@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -74,8 +74,7 @@ static int setaudio(struct xmp_options *o)
 	audio_info_t ainfo;
 	int gain = 128;
 	int bsize = 32 * 1024;
-	char *token;
-	char **parm = o->parm;
+	char *token, **parm;
 
 	parm_init();
 	chkparm1("gain", gain = strtoul(token, NULL, 0));
@@ -104,7 +103,7 @@ static int setaudio(struct xmp_options *o)
 
 	drv_bsd.description = "BSD PCM audio";
 
-	return XMP_OK;
+	return 0;
 }
 
 static int init(struct xmp_context *ctx)
@@ -112,7 +111,7 @@ static int init(struct xmp_context *ctx)
 	if ((audio_fd = open("/dev/sound", O_WRONLY)) == -1)
 		return XMP_ERR_DINIT;
 
-	if (setaudio(o) != XMP_OK)
+	if (setaudio(o) != 0)
 		return XMP_ERR_DINIT;
 
 	return xmp_smix_on(ctx);
