@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -83,8 +83,7 @@ static int setaudio(struct xmp_options *o)
 	int port = AUDIO_OUT_SPEAKER;
 	struct audio_gains agains;
 	struct audio_describe adescribe;
-	char *token;
-	char **parm = o->parm;
+	char *token, **parm;
 	int i;
 
 	parm_init();
@@ -145,7 +144,7 @@ static int setaudio(struct xmp_options *o)
 
 	ioctl(audio_fd, AUDIO_SET_TXBUFSIZE, bsize);
 
-	return XMP_OK;
+	return 0;
 }
 
 static int init(struct xmp_context *ctx)
@@ -153,7 +152,7 @@ static int init(struct xmp_context *ctx)
 	if ((audio_fd = open("/dev/audio", O_WRONLY)) == -1)
 		return XMP_ERR_DINIT;
 
-	if (setaudio(ctl) != XMP_OK)
+	if (setaudio(ctl) != 0)
 		return XMP_ERR_DINIT;
 
 	return xmp_smix_on(ctx);
