@@ -113,8 +113,7 @@ static int setaudio(struct xmp_options *o)
 	int flags;
 	int i;
 	MCI_AMP_OPEN_PARMS AmpOpenParms;
-	char *token;
-	char **parm = o->parm;
+	char *token, **parm;
 
 	//printf( "In SetAudio...\n" );
 
@@ -203,14 +202,14 @@ static int setaudio(struct xmp_options *o)
 	//MixBuffers[2].ulBufferLength = bsize;
 	//MixBuffers[3].ulBufferLength = bsize;
 
-	return XMP_OK;
+	return 0;
 }
 
 static int init(struct xmp_context *ctx)
 {
 	//printf( "In Init...\n" );
 
-	if (setaudio(ctl) != XMP_OK)
+	if (setaudio(ctl) != 0)
 		return XMP_ERR_DINIT;
 
 	/* Start Playback */
