@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -228,7 +228,7 @@ static void bufdump(struct xmp_context *ctx, int i)
 static void shutdown(struct xmp_context *ctx)
 {
 	xmp_smix_off(ctx);
-	ioctl(audio_fd, SNDCTL_DSP_RESET);
+	ioctl(audio_fd, SNDCTL_DSP_RESET, NULL);
 	close(audio_fd);
 }
 
@@ -237,5 +237,5 @@ static void flush()
 	if (!do_sync)
 		return;
 
-	ioctl(audio_fd, SNDCTL_DSP_SYNC);
+	ioctl(audio_fd, SNDCTL_DSP_SYNC, NULL);
 }
