@@ -65,11 +65,10 @@ typedef unsigned short int uint16;
 typedef unsigned int uint32;
 #endif
 
-/* MSVC++6.0 has no long long */
-#ifdef _MSC_VER
+#ifdef _MSC_VER				/* MSVC++6.0 has no long long */
 typedef signed __int64 int64;
 typedef unsigned __int64 uint64;
-#else
+#elif !defined B_BEOS_VERSION		/*BeOS has its own int64 definition */
 typedef unsigned long long uint64;
 typedef signed long long int64;
 #endif
@@ -166,7 +165,7 @@ struct xmp_mod_context {
 	int c4rate;			/* C4 replay rate */
 	int volbase;			/* Volume base */
 	int volume;			/* Global volume */
-	int *vol_xlat;			/* Volume translation table */
+	int *vol_table;			/* Volume translation table */
 	int flags;			/* Copy from options */
 	int quirk;			/* Copy from options */
 
@@ -218,7 +217,8 @@ struct xmp_player_context {
 	struct xmp_channel *xc_data;
 	int *fetch_ctl;
 	int xmp_scan_ord, xmp_scan_row, xmp_scan_num, xmp_bpm;
-	void (*event_callback)(unsigned long);
+	void (*event_callback)(unsigned long, void *);
+	void *callback_data;
 
 	struct xmp_mod_context m;
 };
