@@ -49,21 +49,24 @@ struct patch_info {
 #define XMP_CHN_DUMB		-1
 
 #define parm_init() for (parm = o->parm; *parm; parm++) { \
-	token = strtok (*parm, ":="); token = strtok (NULL, "");
+	char s[80]; strncpy(s, *parm, 80); \
+	token = strtok(s, ":="); token = strtok(NULL, "");
 #define parm_end() }
-#define parm_error() { \
-	fprintf (stderr, "xmp: incorrect parameters in -D %s\n", *parm); \
-	exit (-4); }
+#define parm_error() do { \
+	fprintf(stderr, "xmp: incorrect parameters in -D %s\n", s); \
+	exit(-4); } while (0)
+#define chkparm0(x,y) { \
+	if (!strcmp(s, x)) { \
+	    if (token != NULL) parm_error(); else { y; } } }
 #define chkparm1(x,y) { \
-	if (!strcmp (*parm,x)) { \
-	    if (token == NULL) parm_error ()  else { y; } } }
-#define chkparm2(x,y,z,w) { if (!strcmp (*parm,x)) { \
-	if (2 > sscanf (token, y, z, w)) parm_error (); } }
+	if (!strcmp(s, x)) { \
+	    if (token == NULL) parm_error(); else { y; } } }
+#define chkparm2(x,y,z,w) { if (!strcmp(s, x)) { \
+	if (2 > sscanf(token, y, z, w)) parm_error(); } }
 
 
 /* PROTOTYPES */
 
-void	xmp_drv_register	(struct xmp_drv_info *);
 int	xmp_drv_open		(struct xmp_context *);
 int	xmp_drv_set		(struct xmp_context *);
 void	xmp_drv_close		(struct xmp_context *);
@@ -86,6 +89,7 @@ void	xmp_drv_setpan		(struct xmp_context *, int, int);
 void	xmp_drv_seteffect	(struct xmp_context *, int, int, int);
 int	xmp_drv_cstat		(struct xmp_context *, int);
 void	xmp_drv_resetchannel	(struct xmp_context *, int);
+void	xmp_drv_resetvoice	(struct xmp_context *, int, int);
 void	xmp_drv_reset		(struct xmp_context *);
 double	xmp_drv_sync		(struct xmp_context *, double);
 int	xmp_drv_getmsg		(struct xmp_context *);
@@ -98,7 +102,6 @@ void	xmp_drv_bufdump		(struct xmp_context *);
 int	xmp_drv_loadpatch 	(struct xmp_context *, FILE *, int, int, int,
 				 struct xxm_sample *, char *);
 
-void xmp_init_drivers (void);
 struct xmp_drv_info *xmp_drv_array (void);
 
 #endif /* __XMP_DRIVER_H */
