@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -176,6 +176,7 @@ struct xmp_drv_info {
 	void (*sync) ();
 	int (*writepatch) ();
 	int (*getmsg) ();
+	void *data;
 	struct xmp_drv_info *next;
 };
 
@@ -203,6 +204,7 @@ void xmp_unlink_tempfiles(void);
 struct xmp_options *xmp_get_options(xmp_context);
 
 void xmp_init(xmp_context, int, char **);
+void xmp_deinit(xmp_context);
 void xmp_drv_register(struct xmp_drv_info *);
 int xmp_load_module(xmp_context, char *);
 int xmp_test_module(xmp_context, char *, char *);
@@ -213,7 +215,7 @@ char *xmp_get_driver_description(xmp_context);
 void xmp_set_driver_parameter(struct xmp_options *, char *);
 void xmp_get_driver_cfg(xmp_context, int *, int *, int *, int *);
 void xmp_channel_mute(xmp_context, int, int, int);
-void xmp_register_event_callback(xmp_context, void (*)(unsigned long));
+void xmp_register_event_callback(xmp_context, void (*)(unsigned long, void *), void *);
 int xmp_player_ctl(xmp_context, int, int);
 int xmp_open_audio(xmp_context);
 void xmp_close_audio(xmp_context);
@@ -227,6 +229,7 @@ void xmp_release_module(xmp_context);
 int xmp_verbosity_level(xmp_context, int);
 int xmp_seek_time(xmp_context, int);
 void xmp_init_formats(xmp_context);
+void xmp_deinit_formats(xmp_context);
 int xmp_enable_format(char *, int);
 int xmp_checksum(char *, unsigned int *, unsigned int *);
 
