@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -39,7 +39,9 @@ static int alm_test(FILE *f, char *t, const int start)
 {
     char buf[7];
 
-    fread(buf, 1, 7, f);
+    if (fread(buf, 1, 7, f) < 7)
+	return -1;
+
     if (memcmp(buf, "ALEYMOD", 7) && memcmp(buf, "ALEY MO", 7))
 	return -1;
 
