@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -17,9 +17,10 @@
 #define MAGIC_MNAM	MAGIC4('M','N','A','M')
 
 
-static int arch_test(FILE *, char *, const int);
+static int arch_test (FILE *, char *, const int);
 static int arch_load (struct xmp_context *, FILE *, const int);
 
+
 struct xmp_loader_info arch_loader = {
 	"MUSX",
 	"Archimedes Tracker",
@@ -27,6 +28,13 @@ struct xmp_loader_info arch_loader = {
 	arch_load
 };
 
+#if 0
+static uint8 convert_vol(uint8 vol) {
+/*	return pow(2,6.0-(255.0-vol)/32)+.5; */
+	return vol_table[vol];
+}
+#endif
+
 static int arch_test(FILE *f, char *t, const int start)
 {
 	if (read32b(f) != MAGIC_MUSX)
@@ -95,6 +103,8 @@ static void fix_effect(struct xxm_event *e)
 		break;
 	case 0x1f:			/* 1F xx Set Volume */
 		e->fxt = FX_VOLSET;
+		/* all volumes are logarithmic */
+		/* e->fxp = convert_vol (e->fxp); */
 		break;
 	default:
 		e->fxt = e->fxp = 0;
@@ -242,7 +252,8 @@ static void get_samp(struct xmp_context *ctx, int size, FILE *f)
 	fread(m->xxih[i].name, 1, 20, f);
 	read32l(f);	/* SVOL */
 	read32l(f);
-	m->xxi[i][0].vol = read32l(f) >> 2;
+	/* m->xxi[i][0].vol = convert_vol(read32l(f)); */
+	m->xxi[i][0].vol = read32l(f);
 	read32l(f);	/* SLEN */
 	read32l(f);
 	m->xxs[i].len = read32l(f);
@@ -252,6 +263,7 @@ static void get_samp(struct xmp_context *ctx, int size, FILE *f)
 	read32l(f);	/* RLEN */
 	read32l(f);
 	m->xxs[i].lpe = read32l(f);
+
 	read32l(f);	/* SDAT */
 	read32l(f);
 	read32l(f);	/* 0x00000000 */
@@ -260,9 +272,17 @@ static void get_samp(struct xmp_context *ctx, int size, FILE *f)
 	m->xxi[i][0].sid = i;
 	m->xxi[i][0].pan = 0x80;
 
+	m->vol_table = arch_vol_table;
+	m->volbase = 0xff;
+
 	if (m->xxs[i].lpe > 2) {
 		m->xxs[i].flg = WAVE_LOOPING;
 		m->xxs[i].lpe = m->xxs[i].lps + m->xxs[i].lpe;
+	} else if (m->xxs[i].lpe == 2 && m->xxs[i].lps > 0) {
+		/* non-zero repeat offset and repeat length of 2
+		 * means loop to end of sample */
+		m->xxs[i].flg = WAVE_LOOPING;
+		m->xxs[i].lpe = m->xxs[i].len;
 	}
 
 	xmp_drv_loadpatch(ctx, f, m->xxi[i][0].sid, m->c4rate, XMP_SMP_VIDC,
@@ -289,6 +309,7 @@ static int arch_load(struct xmp_context *ctx, FILE *f, const int start)
 {
 	struct xmp_player_context *p = &ctx->p;
 	struct xmp_mod_context *m = &p->m;
+	int i;
 
 	LOAD_INIT();
 
@@ -320,6 +341,9 @@ static int arch_load(struct xmp_context *ctx, FILE *f, const int start)
 
 	iff_release();
 
+	for (i = 0; i < m->xxh->chn; i++)
+		m->xxc[i].pan = (((i + 3) / 2) % 2) * 0xff;
+
 	return 0;
 }
 
