@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -28,7 +28,9 @@ static int gtk_test(FILE * f, char *t, const int start)
 {
 	char buf[4];
 
-	fread(buf, 4, 1, f);
+	if (fread(buf, 1, 4, f) < 4)
+		return -1;
+
 	if (memcmp(buf, "GTK", 3) || buf[3] > 4)
 		return -1;
 
