@@ -9,6 +9,10 @@
 
 #define IFF_LITTLE_ENDIAN	0x01
 #define IFF_FULL_CHUNK_SIZE	0x02
+#define IFF_CHUNK_ALIGN2	0x04
+#define IFF_CHUNK_ALIGN4	0x08
+#define IFF_SKIP_EMBEDDED	0x10
+#define IFF_CHUNK_TRUNC4	0x20
 
 struct iff_header {
     char form[4];	/* FORM */
