@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -29,7 +29,8 @@ static int mmd3_test(FILE *f, char *t, const int start)
 	char id[4];
 	uint32 offset, len;
 
-	fread(id, 4, 1, f);
+	if (fread(id, 1, 4, f) < 4)
+		return -1;
 
 	if (memcmp(id, "MMD2", 4) && memcmp(id, "MMD3", 4))
 		return -1;
