@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -73,7 +73,8 @@ static int mod_test(FILE *f, char *t, const int start)
     int smp_size, num_pat;
 
     fseek(f, start + 1080, SEEK_SET);
-    fread(buf, 4, 1, f);
+    if (fread(buf, 1, 4, f) < 4)
+	return -1;
 
     if (!strncmp(buf + 2, "CH", 2) && isdigit(buf[0]) && isdigit(buf[1])) {
 	i = (buf[0] - '0') * 10 + buf[1] - '0';
