@@ -92,9 +92,11 @@ int pw_init()
 	pw_register(&pw_fchs);
 	pw_register(&pw_fcm);
 	pw_register(&pw_fuzz);
+	pw_register(&pw_hrt);
 	pw_register(&pw_kris);
 	pw_register(&pw_ksm);
 	pw_register(&pw_mp_id);
+	pw_register(&pw_ntp);
 	pw_register(&pw_p18a);
 	pw_register(&pw_p10c);
 	pw_register(&pw_pru1);
@@ -103,6 +105,7 @@ int pw_init()
 	pw_register(&pw_wn);
 	pw_register(&pw_unic_id);
 	pw_register(&pw_tp3);
+	pw_register(&pw_skyt);
 
 	/* No signature */
 	pw_register(&pw_xann);
@@ -113,6 +116,7 @@ int pw_init()
 	pw_register(&pw_pp21);
 	pw_register(&pw_p50a);
 	pw_register(&pw_p60a);
+	pw_register(&pw_p61a);
 	pw_register(&pw_np2);
 	pw_register(&pw_np1);
 	pw_register(&pw_np3);
@@ -124,6 +128,7 @@ int pw_init()
 	pw_register(&pw_tdd);
 	pw_register(&pw_starpack);
 	pw_register(&pw_gmc);
+	pw_register(&pw_titanics);
 
 	return 0;
 }
@@ -139,11 +144,11 @@ int pw_wizardry(int in, int out, struct pw_format **fmt)
 	uint8 *data;
 	FILE *file_in, *file_out;
 
-	file_in = fdopen (in, "rb");
+	file_in = fdopen(dup(in), "rb");
 	if (file_in == NULL)
 		return -1;
 
-	file_out = fdopen (out, "w+b");
+	file_out = fdopen(dup(out), "w+b");
 
 	if (fstat(fileno(file_in), &st) < 0)
 		in_size = -1;
@@ -160,7 +165,7 @@ int pw_wizardry(int in, int out, struct pw_format **fmt)
 		perror("Couldn't allocate memory");
 		return -1;
 	}
-	fread (data, in_size, 1, file_in);
+	fread(data, in_size, 1, file_in);
 
 
   /********************************************************************/
@@ -193,7 +198,8 @@ done:
 		return -1;
 
 	//pw_crap(format, file_out);
-	fflush(file_out);
+	fclose(file_out);
+	fclose(file_in);
 
 	/*
 	 * ADD: Rip based on size
