@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -43,7 +43,9 @@ static int mtp_test(FILE *f, char *t, const int start)
 {
 	char buf[6];
 
-	fread(buf, 6, 1, f);
+	if (fread(buf, 1, 6, f) < 6)
+		return -1;
+
 	if (memcmp(buf, "SONGOK", 6) && memcmp(buf, "IAN92a", 6))
 		return -1;
 
