@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -45,12 +45,14 @@ static int stx_test(FILE *f, char *t, const int start)
     char buf[8];
 
     fseek(f, start + 20, SEEK_SET);
-    fread(buf, 8, 1, f);
+    if (fread(buf, 1, 8, f) < 8)
+	return -1;
     if (memcmp(buf, "!Scream!", 8) && memcmp(buf, "BMOD2STM", 8))
 	return -1;
 
     fseek(f, start + 60, SEEK_SET);
-    fread(buf, 4, 1, f);
+    if (fread(buf, 1, 4, f) < 4)
+	return -1;
     if (memcmp(buf, "SCRM", 4))
 	return -1;
 
