@@ -34,6 +34,8 @@
 #include <config.h>
 #endif
 
+#ifndef HAVE_GETOPT_H
+
 #if !defined (__STDC__) || !__STDC__
 /* This is a separate conditional since some stdc systems
    reject `defined (const)'.  */
@@ -1000,3 +1002,5 @@ main (argc, argv)
 }
 
 #endif /* TEST */
+
+#endif /* HAVE_GETOPT_H */
