@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -37,6 +37,9 @@ void *xmp_create_context()
 	if (ctx == NULL)
 		return NULL;
 
+	/* Explicitly initialize to keep valgrind happy */
+	*ctx->p.m.name = *ctx->p.m.type = 0;
+
 	o = &ctx->o;
 
 	w = 0x00ff;
@@ -82,12 +85,17 @@ void xmp_init(xmp_context ctx, int argc, char **argv)
 		_xmp_read_rc((struct xmp_context *)ctx);
 }
 
-inline int xmp_open_audio(xmp_context ctx)
+void xmp_deinit(xmp_context ctx)
+{
+	xmp_deinit_formats(ctx);
+}
+
+int xmp_open_audio(xmp_context ctx)
 {
 	return xmp_drv_open((struct xmp_context *)ctx);
 }
 
-inline void xmp_close_audio(xmp_context ctx)
+void xmp_close_audio(xmp_context ctx)
 {
 	xmp_drv_close((struct xmp_context *)ctx);
 }
@@ -100,11 +108,12 @@ void xmp_set_driver_parameter(struct xmp_options *o, char *s)
 	drv_parm++;
 }
 
-inline void xmp_register_event_callback(xmp_context ctx, void (*cb) (unsigned long))
+void xmp_register_event_callback(xmp_context ctx, void (*cb)(unsigned long, void *), void *data)
 {
 	struct xmp_player_context *p = &((struct xmp_context *)ctx)->p;
 
 	p->event_callback = cb;
+	p->callback_data = data;
 }
 
 void xmp_channel_mute(xmp_context ctx, int from, int num, int on)
@@ -160,22 +169,22 @@ int xmp_player_ctl(xmp_context ctx, int cmd, int arg)
 	return 0;
 }
 
-inline int xmp_player_start(xmp_context ctx)
+int xmp_player_start(xmp_context ctx)
 {
 	return _xmp_player_start((struct xmp_context *)ctx);
 }
 
-inline int xmp_player_frame(xmp_context ctx)
+int xmp_player_frame(xmp_context ctx)
 {
 	return _xmp_player_frame((struct xmp_context *)ctx);
 }
 
-inline void xmp_player_end(xmp_context ctx)
+void xmp_player_end(xmp_context ctx)
 {
 	_xmp_player_end((struct xmp_context *)ctx);
 }
 
-inline void xmp_play_buffer(xmp_context ctx)
+void xmp_play_buffer(xmp_context ctx)
 {
 	xmp_drv_bufdump((struct xmp_context *)ctx);
 }
