@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -51,6 +51,7 @@ int decrunch_muse	(FILE *, FILE *);
 int decrunch_lzx	(FILE *, FILE *);
 int decrunch_oxm	(FILE *, FILE *);
 int decrunch_xfd	(FILE *, FILE *);
+int decrunch_s404	(FILE *, FILE *);
 int test_oxm		(FILE *);
 char *test_xfd		(unsigned char *, int);
 
@@ -86,18 +87,22 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 
     packer = cmd = NULL;
     builtin = res = 0;
-    get_temp_dir(tmp, PATH_MAX);
+
+    if (get_temp_dir(tmp, PATH_MAX) < 0)
+	return 0;
+
     strncat(tmp, "xmp_XXXXXX", PATH_MAX);
 
     fseek(*f, 0, SEEK_SET);
-    fread(b, 1, 1024, *f);
+    if (fread(b, 1, 1024, *f) < 100)	/* minimum valid file size */
+	return 0;
 
 #if defined __AMIGA__ && !defined __AROS__
     if (packer = test_xfd(b, 1024)) {
 	builtin = BUILTIN_XFD;
     } else
 #endif
-    if (b[0] == 'P' && b[1] == 'K') {
+    if (b[0] == 'P' && b[1] == 'K' && b[2] == 0x03 && b[3] == 0x04) {
 	packer = "Zip";
 #if defined WIN32
 	cmd = "unzip -pqqC \"%s\" -x readme *.diz *.nfo *.txt *.exe *.com "
@@ -141,35 +146,34 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	fprintf( stderr, "I hope that the default command will work if a OS/2 version is found/created!\n" );
 #endif
 	cmd = "uncompress -c \"%s\"";
-    } else if (b[0] == 'P' && b[1] == 'P' && b[2] == '2' && b[3] == '0') {
+    } else if (memcmp(b, "PP20", 4) == 0) {
 	packer = "PowerPack";
 	builtin = BUILTIN_PP;
-    } else if (b[0] == 'X' && b[1] == 'P' && b[2] == 'K' && b[3] == 'F' &&
-	b[8] == 'S' && b[9] == 'Q' && b[10] == 'S' && b[11] == 'H') {
+    } else if (memcmp(b, "XPKF", 4) == 0 && memcmp(b + 8, "SQSH", 4) == 0) {
 	packer = "SQSH";
 	builtin = BUILTIN_SQSH;
     } else if (!memcmp(b, "Archive\0", 8)) {
 	packer = "ArcFS";
 	builtin = BUILTIN_ARCFS;
-    } else if (b[0] == 'z' && b[1] == 'i' && b[2] == 'R' && b[3] == 'C' &&
-		b[4] == 'O' && b[5] == 'N' && b[6] == 'i' && b[7] == 'a') {
+    } else if (memcmp(b, "ziRCONia", 8) == 0) {
 	packer = "MMCMP";
 	builtin = BUILTIN_MMCMP;
-    } else if (b[0] == 'M' && b[1] == 'U' && b[2] == 'S' && b[3] == 'E' &&
-		b[4] == 0xde && b[5] == 0xad && b[6] == 0xbe && b[7] == 0xaf) {
+    } else if (memcmp(b, "MUSE", 4) == 0 && readmem32b(b + 4) == 0xdeadbeaf) {
 	packer = "J2B MUSE";
 	builtin = BUILTIN_MUSE;
-    } else if (b[0] == 'M' && b[1] == 'U' && b[2] == 'S' && b[3] == 'E' &&
-		b[4] == 0xde && b[5] == 0xad && b[6] == 0xba && b[7] == 0xbe) {
+    } else if (memcmp(b, "MUSE", 4) == 0 && readmem32b(b + 4) == 0xdeadbabe) {
 	packer = "MOD2J2B MUSE";
 	builtin = BUILTIN_MUSE;
-    } else if (b[0] == 76 && b[1] == 90 && b[2] == 88) {
+    } else if (memcmp(b, "LZX", 3) == 0) {
 	packer = "LZX";
 	builtin = BUILTIN_LZX;
-    } else if (b[0] == 'R' && b[1] == 'a' && b[2] == 'r') {
+    } else if (memcmp(b, "Rar", 3) == 0) {
 	packer = "rar";
 	cmd = "unrar p -inul -xreadme -x*.diz -x*.nfo -x*.txt "
 	    "-x*.exe -x*.com \"%s\"";
+    } else if (memcmp(b, "S404", 4) == 0) {
+	packer = "Stonecracker";
+	builtin = BUILTIN_S404;
 #if !defined WIN32 && !defined __AMIGA__
     } else if (test_oxm(*f) == 0) {
 	packer = "oggmod";
@@ -215,6 +219,12 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     if (packer == NULL)
 	return 0;
 
+#ifdef ANDROID
+    /* Don't use external helpers in android */
+    if (cmd)
+	return 0;
+#endif
+
     reportv(ctx, 0, "Depacking %s file... ", packer);
 
     temp = calloc(sizeof (struct tmpfilename), 1);
@@ -238,13 +248,12 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     }
 
     if (cmd) {
-	int n, lsize;
-	char *line, *buf;
+#define BSIZE 0x4000
+	int n;
+	char line[1024], buf[BSIZE];
 	FILE *p;
 
-	lsize = strlen(cmd) + strlen(*s) + 16;
-	line = malloc(lsize);
-	snprintf(line, lsize, cmd, *s);
+	snprintf(line, 1024, cmd, *s);
 
 #ifdef WIN32
 	/* Note: The _popen function returns an invalid file handle, if
@@ -261,21 +270,10 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 #endif
 	    reportv(ctx, 0, "failed\n");
 	    fclose(t);
-	    free(line);
 	    goto err;
 	}
-	free (line);
-#define BSIZE 0x4000
-	if ((buf = malloc (BSIZE)) == NULL) {
-	    reportv(ctx, 0, "failed\n");
-	    pclose (p);
-	    fclose (t);
-	    goto err;
-	}
-	while ((n = fread(buf, 1, BSIZE, p)) > 0) {
+	while ((n = fread(buf, 1, BSIZE, p)) > 0)
 	    fwrite(buf, 1, n, t);
-	} 
-	free(buf);
 	pclose (p);
     } else {
 	switch (builtin) {
@@ -300,6 +298,9 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	case BUILTIN_LZX:    
 	    res = decrunch_lzx(*f, t);
 	    break;
+	case BUILTIN_S404:
+	    res = decrunch_s404(*f, t);
+	    break;
 #if !defined WIN32 && !defined __MINGW32__ && !defined __AMIGA__
 	case BUILTIN_OXM:
 	    res = decrunch_oxm(*f, t);
@@ -315,6 +316,7 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 
     if (res < 0) {
 	reportv(ctx, 0, "failed\n");
+	fclose(t);
 	goto err;
     }
 
@@ -425,7 +427,6 @@ static int crunch_ratio(struct xmp_context *ctx, int awe)
     return ratio;
 }
 
-
 int xmp_test_module(xmp_context ctx, char *s, char *n)
 {
     FILE *f;
@@ -448,6 +449,11 @@ int xmp_test_module(xmp_context ctx, char *s, char *n)
     if (fstat(fileno(f), &st) < 0)	/* get size after decrunch */
 	goto err;
 
+    if (st.st_size < 500)		/* set minimum valid module size */
+	goto err;
+
+    if (n) *n = 0;			/* reset name prior to testing */
+
     list_for_each(head, &loader_list) {
 	li = list_entry(head, struct xmp_loader_info, list);
 	if (li->enable) {
@@ -462,6 +468,7 @@ int xmp_test_module(xmp_context ctx, char *s, char *n)
 
 err:
     fclose (f);
+    xmp_unlink_tempfiles();
     return -1;
 }
 
@@ -530,7 +537,7 @@ int xmp_load_module(xmp_context ctx, char *s)
     m->c4rate = C4_PAL_RATE;
     m->volbase = 0x40;
     m->volume = 0x40;
-    m->vol_xlat = NULL;
+    m->vol_table = NULL;
     /* Reset control for next module */
     m->flags = o->flags & ~XMP_CTL_FILTER;	/* verify this later */
     m->quirk = o->quirk;
@@ -569,6 +576,10 @@ int xmp_load_module(xmp_context ctx, char *s)
 	    _D(_D_WARN "load format: %s (%s)", li->id, li->name);
 	    if ((i = li->loader((struct xmp_context *)ctx, f, 0) == 0)) {
 		crc = cksum(f);
+	        break;
+	    } else {
+		report("can't load module, possibly corrupted file\n");
+		i = -1;
 		break;
 	    }
 	}
