@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -18,7 +18,7 @@ inline uint8 read8(FILE *f)
 	return (uint8)fgetc(f);
 }
 
-inline int8 read8s(FILE *f)
+int8 read8s(FILE *f)
 {
 	return (int8)fgetc(f);
 }
