@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -15,6 +15,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
+#ifdef ANDROID
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#endif
 #include "common.h"
 
 int report(char *fmt, ...)
@@ -68,9 +73,15 @@ int get_temp_dir(char *buf, int size)
 	strncpy(buf, tmp ? tmp : def, size);
 	strncat(buf, "\\", size);
 #elif defined __AMIGA__
-	char *def = "T:";
-
-	strncpy(buf, def, size);
+	strncpy(buf, "T:", size);
+#elif defined ANDROID
+	struct stat st;
+	stat("/sdcard/xmp", &st);
+	if (!S_ISDIR(st.st_mode)) {
+		if (mkdir("/sdcard/xmp", 0777) < 0)
+			return -1;
+	}
+	strncpy(buf, "/sdcard/xmp", size);
 #else
 	char *def = "/tmp";
 	char *tmp = getenv("TMPDIR");
