@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1997-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1997-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -585,7 +585,7 @@ void xmp_smix_echoback(struct xmp_context *ctx, int msg)
     struct xmp_player_context *p = &ctx->p;
     struct xmp_smixer_context *s = &ctx->s;
 
-    p->event_callback(s->echo_msg = msg);
+    p->event_callback(s->echo_msg = msg, p->callback_data);
 }
 
 
