@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2009 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2010 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -89,7 +89,7 @@ static void play_channel (struct xmp_context *, int, int);
 /* #include "effects.c" */
 
 
-static void dummy(unsigned long ul)
+static void dummy(unsigned long ul, void *data)
 {
     /* dummy */
 }
@@ -463,20 +463,23 @@ static int fetch_channel(struct xmp_context *ctx, struct xxm_event *e, int chn,
 	xc->s_end = xc->period = note_to_period(note, xc->finetune,
 			m->xxh->flg & XXM_FLG_LINEAR);
 
-	xc->y_idx = xc->t_idx = 0;	      /* #?# Onde eu coloco isso? */
+	xc->y_idx = xc->t_idx = 0;	/* H: where should I put this? */
 
 	SET(ECHOBACK);
     }
 
-    if (xc->key == 0xff || XXIM.ins[xc->key] == 0xff)
+    if (xc->key < 0 || XXIM.ins[xc->key] == 0xff)
 	return 0;
 
     if (TEST(RESET_ENV)) {
 	/* xc->fadeout = 0x8000; -- moved to fetch */
 	RESET(RELEASE | FADEOUT);
-	xc->gvl = XXI[XXIM.ins[xc->key]].gvl;   /* #?# Onde eu coloco isso? */
-	xc->insvib_swp = XXI->vsw;	      /* #?# Onde eu coloco isso? */
-	xc->insvib_idx = 0;		     /* #?# Onde eu coloco isso? */
+
+	/* H: where should I put these? */
+	xc->gvl = XXI[XXIM.ins[xc->key]].gvl;
+	xc->insvib_swp = XXI->vsw;
+	xc->insvib_idx = 0;
+
 	xc->v_idx = xc->p_idx = xc->f_idx = 0;
 	xc->cutoff = XXI->ifc & 0x80 ? (XXI->ifc - 0x80) * 2 : 0xff;
 	xc->resonance = XXI->ifr & 0x80 ? (XXI->ifr - 0x80) * 2 : 0;
@@ -487,7 +490,7 @@ static int fetch_channel(struct xmp_context *ctx, struct xxm_event *e, int chn,
 	SET(ECHOBACK | NEW_VOL);
     }
 
-    if (HAS_QUIRK(XMP_QRK_ST3GVOL) && TEST(NEW_VOL) && m->volbase)
+    if (HAS_QUIRK(XMP_QRK_ST3GVOL) && TEST(NEW_VOL))
 	xc->volume = xc->volume * m->volume / m->volbase;
 
     return 0;
@@ -610,9 +613,12 @@ static void play_channel(struct xmp_context *ctx, int chn, int t)
 	(HAS_QUIRK(XMP_QRK_ST3GVOL) ? 0x40 : m->volume) *
 	xc->mastervol / 0x40 * ((int)finalvol * 0x40 / p->gvol_base)) >> 18;
 
-    /* Volume translation table (for PTM) */
-    if (m->vol_xlat)
-	finalvol = m->vol_xlat[finalvol >> 4] << 4;
+    /* Volume translation table (for PTM, ARCH, COCO) */
+    if (m->vol_table) {
+	finalvol = m->volbase == 0xff ?
+		m->vol_table[finalvol >> 2] << 2 :
+		m->vol_table[finalvol >> 4] << 4;
+    }
 
     if (m->xxh->flg & XXM_FLG_INSVOL)
 	finalvol = (finalvol * XXIH.vol * xc->gvl) >> 12;
@@ -839,9 +845,6 @@ int _xmp_player_start(struct xmp_context *ctx)
 	struct flow_control *f = &p->flow;
 	int ret;
 
-	if (m->xxh->len == 0 || m->xxh->chn == 0)
-		return 0;
-
 	if (p->event_callback == NULL)
 		p->event_callback = dummy;
 
@@ -850,6 +853,17 @@ int _xmp_player_start(struct xmp_context *ctx)
 	p->pos = f->ord = o->start;
 	f->frame = 0;
 	f->row = 0;
+	f->time = 0;
+
+	if (m->xxh->len == 0 || m->xxh->chn == 0) {
+		/* set variables to sane state */
+		m->flags &= ~XMP_CTL_LOOP;
+		f->ord = p->xmp_scan_ord = 0;
+		f->row = p->xmp_scan_row = 0;
+		f->end_point = 0;
+		return 0;
+	}
+
 	f->num_rows = m->xxp[m->xxo[f->ord]]->rows;
 
 	/* Skip invalid patterns at start (the seventh laboratory.it) */
@@ -882,7 +896,6 @@ int _xmp_player_start(struct xmp_context *ctx)
 	return 0;
 }
 
-
 int _xmp_player_frame(struct xmp_context *ctx)
 {
 	struct xmp_player_context *p = &ctx->p;
@@ -892,7 +905,7 @@ int _xmp_player_frame(struct xmp_context *ctx)
 	struct flow_control *f = &p->flow;
 
 	if (p->pause) {
-		p->event_callback(0);
+		p->event_callback(0, p->callback_data);
 		return 0;
 	}
 
@@ -954,7 +967,6 @@ int _xmp_player_frame(struct xmp_context *ctx)
 	}
 
 
-
 	xmp_drv_echoback(ctx, (f->frame << 4) | XMP_ECHO_FRM);
 	play_frame(ctx, f->frame);
 
@@ -964,6 +976,7 @@ int _xmp_player_frame(struct xmp_context *ctx)
 	if (HAS_QUIRK(XMP_QRK_MEDBPM)) {
 		xmp_drv_sync(ctx, p->tick_time * 33 / 125);
 		f->playing_time += m->rrate * 33 / (100 * p->xmp_bpm * 125);
+		f->time += m->rrate * 33 / (100 * p->xmp_bpm * 125);
 	} else {
 		xmp_drv_sync(ctx, p->tick_time);
 		f->playing_time += m->rrate / (100 * p->xmp_bpm);
@@ -1039,17 +1052,23 @@ next_order:
 void _xmp_player_end(struct xmp_context *ctx)
 {
 	struct xmp_player_context *p = &ctx->p;
+	struct xmp_mod_context *m = &p->m;
 	struct flow_control *f = &p->flow;
 
 	xmp_drv_echoback(ctx, XMP_ECHO_END);
+
 	while (xmp_drv_getmsg(ctx) != XMP_ECHO_END)
 		xmp_drv_bufdump(ctx);
+
 	xmp_drv_stoptimer(ctx);
+	xmp_drv_off(ctx);
+
+	if (m->xxh->len == 0 || m->xxh->chn == 0)
+                return;
 
 	free(p->xc_data);
 	free(f->loop_start);
 	free(f->loop_stack);
 	free(p->fetch_ctl);
 
-	xmp_drv_off(ctx);
 }
