@@ -21,8 +21,14 @@
 #include "common.h"
 #include "driver.h"
 
+#if __AUDACIOUS_PLUGIN_API__ >= 12
+#define CONST12 const
+#else
+#define CONST12
+#endif
+
 static void	init		(void);
-static int	is_our_file	(char *);
+static int	is_our_file	(CONST12 char *);
 static void	play_file	(InputPlayback *);
 static void	stop		(InputPlayback *);
 static void	mod_pause	(InputPlayback *, short);
@@ -30,14 +36,19 @@ static void	seek		(InputPlayback *, int);
 static int	get_time	(InputPlayback *);
 static void	*play_loop	(void *);
 static void	aboutbox	(void);
+#if __AUDACIOUS_PLUGIN_API__ >= 8
+static int	is_our_file_from_vfs(CONST12 char *, VFSFile *);
+#endif
+#if __AUDACIOUS_PLUGIN_API__ < 12
 static void	get_song_info	(char *, char **, int *);
+#endif
 static void	configure	(void);
 static void	config_ok	(GtkWidget *, gpointer);
 static void	mseek		(InputPlayback *, gulong);
 static void	cleanup		(void);
 
 #if __AUDACIOUS_PLUGIN_API__ >= 2
-static Tuple	*get_song_tuple	(char *);
+static Tuple	*get_song_tuple	(CONST12 char *);
 #endif
 
 static GThread *decode_thread;
@@ -93,6 +104,7 @@ static GtkWidget *about_window = NULL;
 int skip = 0;
 static short audio_open = FALSE;
 
+/* Filtering files by suffix is really stupid. */
 static gchar *fmts[] = {
 	"xm", "mod", "m15", "it", "s2m", "s3m", "stm", "stx", "med", "dmf",
 	"mtm", "ice", "imf", "ptm", "mdl", "ult", "liq", "psm", "amf",
@@ -114,7 +126,12 @@ InputPlugin xmp_ip = {
 	.pause		= mod_pause,
 	.seek		= seek,
 	.get_time	= get_time,
+#if __AUDACIOUS_PLUGIN_API__ >= 8
+	.is_our_file_from_vfs = is_our_file_from_vfs,
+#endif
+#if __AUDACIOUS_PLUGIN_API__ < 12
 	.get_song_info	= get_song_info,
+#endif
 	.cleanup	= cleanup,
 #if __AUDACIOUS_PLUGIN_API__ >= 2
 	.get_song_tuple	= get_song_tuple,
@@ -178,6 +195,8 @@ static void aboutbox()
 	}
 
 	about_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_type_hint(GTK_WINDOW(about_window),
+					GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_object_set_data(GTK_OBJECT(about_window),
 		"about_window", about_window);
 	gtk_window_set_title(GTK_WINDOW(about_window),"About the XMP Plugin");
@@ -245,7 +264,7 @@ static void aboutbox()
 }
 
 
-xmp_context ctx;
+static xmp_context ctx;
 
 
 static void stop(InputPlayback *ipb)
@@ -284,7 +303,11 @@ static void mseek(InputPlayback *ipb, unsigned long time)
 			if (i > 0)
 				i--;
 			a = xmp_ord_set(ctx, i);
+#if __AUDACIOUS_PLUGIN_API__ < 13
 			ipb->output->flush(p->m.xxo_info[i].time);
+#else
+			ipb->output->flush(p->m.xxo_info[i].time / 1000);
+#endif
 			break;
 		}
 	}
@@ -303,7 +326,11 @@ static int get_time(InputPlayback *ipb)
 	if (!ipb->playing)
 		return -1;
 
+#if __AUDACIOUS_PLUGIN_API__ < 13
 	return ipb->output->output_time();
+#else
+	return ipb->output->written_time();
+#endif
 }
 
 
@@ -361,17 +388,33 @@ static void cleanup()
 }
 
 
-static int is_our_file(char *filename)
+static int is_our_file(CONST12 char *filename)
 {
 	_D("filename = %s", filename);
-	strip_vfs(filename);		/* Sorry, no VFS support */
+	strip_vfs((char *)filename);		/* Sorry, no VFS support */
 
-	if (xmp_test_module(ctx, filename, NULL) == 0)
+	if (xmp_test_module(ctx, (char *)filename, NULL) == 0)
 		return 1;
 
 	return 0;
 }
 
+#if __AUDACIOUS_PLUGIN_API__ >= 8
+
+static int is_our_file_from_vfs(CONST12 char* filename, VFSFile *vfsfile)
+{
+	_D("filename = %s", filename);
+	strip_vfs((char *)filename);		/* Sorry, no VFS support */
+
+	if (xmp_test_module(ctx, (char *)filename, NULL) == 0)
+		return 1;
+
+	return 0;
+}
+
+#endif
+
+#if __AUDACIOUS_PLUGIN_API__ < 12
 
 static void get_song_info(char *filename, char **title, int *length)
 {
@@ -406,10 +449,11 @@ static void get_song_info(char *filename, char **title, int *length)
 	xmp_free_context(ctx2);
 }
 
+#endif
 
 #if __AUDACIOUS_PLUGIN_API__ >= 2
 
-static Tuple *get_song_tuple(char *filename)
+static Tuple *get_song_tuple(CONST12 char *filename)
 {
 	Tuple *tuple;
 	xmp_context ctx2;
@@ -418,7 +462,7 @@ static Tuple *get_song_tuple(char *filename)
 	struct xmp_options *opt;
 
 	_D("filename = %s", filename);
-	strip_vfs(filename);		/* Sorry, no VFS support */
+	strip_vfs((char *)filename);		/* Sorry, no VFS support */
 
 	tuple = aud_tuple_new_from_filename(filename);
 
@@ -429,7 +473,7 @@ static Tuple *get_song_tuple(char *filename)
 	opt->skipsmp = 1;	/* don't load samples */
 
 	g_static_mutex_lock(&load_mutex);
-	lret = xmp_load_module(ctx2, filename);
+	lret = xmp_load_module(ctx2, (char *)filename);
 	g_static_mutex_unlock(&load_mutex);
 
 	if (lret < 0) {
@@ -541,7 +585,9 @@ static void play_file(InputPlayback *ipb)
 	g_static_mutex_unlock(&load_mutex);
 
 	if (lret < 0) {
+#if __AUDACIOUS_PLUGIN_API__ < 13
 		xmp_ip.set_info_text("Error loading mod");
+#endif
 		ipb->playing = 0;
 		return;
 	}
@@ -550,8 +596,13 @@ static void play_file(InputPlayback *ipb)
 	xmp_get_module_info(ctx, &xmp_cfg.mod_info);
 
 #if __AUDACIOUS_PLUGIN_API__ >= 2
+#if __AUDACIOUS_PLUGIN_API__ >= 12
+	ipb->set_params(ipb, xmp_cfg.mod_info.name, lret,
+		xmp_cfg.mod_info.chn * 1000, opt->freq, channelcnt);
+#else
 	ipb->set_params(ipb, xmp_cfg.mod_info.name, lret, 0,
-					opt->freq, channelcnt);
+						opt->freq, channelcnt);
+#endif
 	ipb->playing = 1;
 	ipb->eof = 0;
 	ipb->error = FALSE;
@@ -635,7 +686,8 @@ static void configure()
 	}
 
 	xmp_conf_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
+	gtk_window_set_type_hint(GTK_WINDOW(xmp_conf_window),
+					GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_object_set_data(GTK_OBJECT(xmp_conf_window),
 		"xmp_conf_window", xmp_conf_window);
 	gtk_window_set_title(GTK_WINDOW(xmp_conf_window), "XMP Configuration");
