@@ -190,7 +190,7 @@ static void aboutbox()
 }
 
 
-xmp_context ctx;
+static xmp_context ctx;
 
 
 static void stop()
